Source documentation:
=====================


:mod:`coral` -- Main Package
****************************

.. automodule:: coral
   :members:
   :imported-members:


:mod:`coral.analysis` -- Sequence analysis
------------------------------------------

.. automodule:: coral.analysis
   :members:
   :imported-members:


:mod:`coral.constants` -- Data and constants
--------------------------------------------

.. automodule:: coral.constants
   :members:
   :imported-members:


:mod:`coral.database` -- Scientific database access
---------------------------------------------------

.. automodule:: coral.database
   :members:
   :imported-members:


:mod:`coral.design` -- Design sequences, primers, etc
------------------------------------------------------

.. automodule:: coral.design
   :members:
   :imported-members:


:mod:`coral.reaction` -- Cloning and molecular genetics reactions
-----------------------------------------------------------------

.. automodule:: coral.reaction
   :members:
   :imported-members:


:mod:`coral.seqio` -- Read and write sequences
----------------------------------------------

.. automodule:: coral.seqio
   :members:
   :imported-members:


.. :mod:`coral.sequence` -- DNA, RNA, and Peptide sequences
.. --------------------------------------------------------
..
.. .. automodule:: coral.sequence
..    :members:
..    :imported-members:
